@@ -1,4 +1,5 @@
 import os
+import sys
 
 if os.name == "nt":
     from colorama import init
@@ -17,10 +18,11 @@ class tc:
     BOLD = '\033[1m'
     UNDERLINE = '\033[4m'
     ENDC = '\033[0m'
+    ISATTY = sys.stdout.isatty()
 
     @classmethod
     def _wrap (cls, s, c):
-        return "{}{}{}".format (c, s, cls.ENDC)
+        return cls.ISATTY and s or "{}{}{}".format (c, s, cls.ENDC)
 
     @classmethod
     def default (cls, s):
